{% extends "base.html" %}
{% load uni_form_tags %}
{% load i18n %}

{% block title %}{% trans "Support our case" %}{% endblock %}

{% block main %}

<h1>{% trans "Support our case" %}</h1>

<form action="" method="post" class="uniForm">
    {% csrf_token %}
    <fieldset class="blockLabels">
        {{ form|as_uni_form }}
    </fieldset>
    <button type="submit">{% trans "Send" %}</button>
</form>

{% endblock %}
