{% extends "base.html" %}
{% load i18n %}
{% load uni_form_tags %}

{% block title %}{% trans "Update payment site configuration" %}{% endblock %}

{% block main %}
<h1>{% trans "Update payment site configuration" %}</h1>
<form method="post" action="" class="uniForm">
    {% csrf_token %}
    <fieldset class="blockLabels">
        {{ form|as_uni_form }}
    </fieldset>
    <button type="submit">{% trans "Update" %}</button>
</form>
{% endblock %}
